Contributors
============

Lead:

- `@ericmjl <https://github.com/ericmjl/pyjanitor/pulls?q=is%3Apr+author%3Aericmjl>`_

With thanks to the following contributors:

- `@JoshuaC3 <https://github.com/ericmjl/pyjanitor/pulls?q=is%3Apr+author%3AJoshuaC3>`_
